@@ -2,22 +2,20 @@
 # Copyright (c) Vispy Development Team. All Rights Reserved.
 # Distributed under the (new) BSD License. See LICENSE.txt for more info.
 
-"""
-Implements the global singleton app object.
-
-"""
+"""Implements the global singleton app object."""
 
 from __future__ import division
 
+import builtins
 import os
 import sys
 
-from . import backends, inputhook
+from . import backends
 from .backends import CORE_BACKENDS, BACKEND_NAMES, BACKENDMAP, TRIED_BACKENDS
 from .. import config
 from .base import BaseApplicationBackend as ApplicationBackend  # noqa
+from ._detect_eventloop import _get_running_interactive_framework
 from ..util import logger
-from ..ext import six
 
 
 class Application(object):
@@ -57,8 +55,7 @@ class Application(object):
 
     @property
     def backend_name(self):
-        """ The name of the GUI backend that this app wraps.
-        """
+        """The name of the GUI backend that this app wraps."""
         if self._backend is not None:
             return self._backend._vispy_get_backend_name()
         else:
@@ -66,23 +63,21 @@ class Application(object):
 
     @property
     def backend_module(self):
-        """ The module object that defines the backend.
-        """
+        """The module object that defines the backend."""
         return self._backend_module
 
     def process_events(self):
-        """ Process all pending GUI events. If the mainloop is not
+        """Process all pending GUI events. If the mainloop is not
         running, this should be done regularly to keep the visualization
         interactive and to keep the event system going.
         """
         return self._backend._vispy_process_events()
 
     def sleep(self, duration_sec):
-        """ Sleep for the given duration in seconds.
+        """Sleep for the given duration in seconds.
 
         This is used to reduce
         CPU stress when VisPy is run in interactive mode.
-        see inputhook.py for details
 
         Parameters
         ----------
@@ -92,21 +87,19 @@ class Application(object):
         self._backend._vispy_sleep(duration_sec)
 
     def create(self):
-        """ Create the native application.
-        """
+        """Create the native application."""
         # Ensure that the native app exists
         self.native
 
     def is_interactive(self):
-        """ Determine if the user requested interactive mode.
-        """
+        """Determine if the user requested interactive mode."""
         # The Python interpreter sets sys.flags correctly, so use them!
         if sys.flags.interactive:
             return True
 
         # IPython does not set sys.flags when -i is specified, so first
         # check it if it is already imported.
-        if '__IPYTHON__' not in dir(six.moves.builtins):
+        if not hasattr(builtins, '__IPYTHON__'):
             return False
 
         # Then we check the application singleton and determine based on
@@ -128,12 +121,22 @@ class Application(object):
             # 'get_ipython' is available in globals when running from
             # IPython/Jupyter
             ip = get_ipython()
-            return ip.has_trait('kernel')
+            if ip.has_trait('kernel'):
+                # There doesn't seem to be an easy way to detect the frontend
+                # That said, if using a kernel, the user can choose to have an
+                # event loop, we therefore make sure the event loop isn't
+                # specified before assuming it is a notebook
+                # https://github.com/vispy/vispy/issues/1708
+                # https://github.com/ipython/ipython/issues/11920
+                return _get_running_interactive_framework() is None
+            else:
+                # `jupyter console` is used
+                return False
         except NameError:
             return False
 
     def run(self, allow_interactive=True):
-        """ Enter the native GUI event loop.
+        """Enter the native GUI event loop.
 
         Parameters
         ----------
@@ -145,14 +148,19 @@ class Application(object):
             immediately and rely on the interpreter's input loop to be run
             after script execution.
         """
-
-        if allow_interactive and self.is_interactive():
-            inputhook.set_interactive(enabled=True, app=self)
-        else:
+        if os.getenv("_VISPY_RUNNING_GALLERY_EXAMPLES"):
+            # Custom sphinx-gallery scraper in doc/conf.py will handle
+            # rendering/running the application. To make example scripts look
+            # like what a user actually has to run to view the window, we let
+            # them run "app.run()" but immediately return here.
+            # Without this the application would block until someone closed the
+            # window that opens.
+            return 0
+        elif not allow_interactive or not self.is_interactive():
             return self._backend._vispy_run()
 
     def reuse(self):
-        """ Called when the application is reused in an interactive session.
+        """Called when the application is reused in an interactive session.
         This allow the backend to do stuff in the client when `use_app()` is
         called multiple times by the user. For example, the notebook backends
         need to inject JavaScript code as soon as `use_app()` is called.
@@ -160,19 +168,16 @@ class Application(object):
         return self._backend._vispy_reuse()
 
     def quit(self):
-        """ Quit the native GUI event loop.
-        """
+        """Quit the native GUI event loop."""
         return self._backend._vispy_quit()
 
     @property
     def native(self):
-        """ The native GUI application instance.
-        """
+        """The native GUI application instance."""
         return self._backend._vispy_get_native_app()
 
     def _use(self, backend_name=None):
-        """Select a backend by name. See class docstring for details.
-        """
+        """Select a backend by name. See class docstring for details."""
         # See if we're in a specific testing mode, if so DONT check to see
         # if it's a valid backend. If it isn't, it's a good thing we
         # get an error later because we should have decorated our test
@@ -190,7 +195,7 @@ class Application(object):
             backend_name = test_name.lower()
             assert backend_name in BACKENDMAP
         elif self.is_notebook():
-            backend_name = 'ipynb_webgl'
+            backend_name = 'jupyter_rfb'
 
         # Should we try and load any backend, or just this specific one?
         try_others = backend_name is None
@@ -241,14 +246,13 @@ class Application(object):
                            'side effects.' %
                            (native_module_name, name, str(mod.why_not)))
                     logger.warning(msg)
-                else:
-                    if backend_name is not None:
-                        # Inform only if one isn't available
-                        logger.info(msg)
+                elif backend_name is not None:
+                    # Inform only if one isn't available
+                    logger.warning(msg)
             else:
                 # Success!
                 self._backend_module = mod
-                logger.debug('Selected backend %s' % module_name)
+                logger.info('Selected backend %s' % module_name)
                 break
         else:
             raise RuntimeError('Could not import any of the backends. '
