@@ -43,11 +43,11 @@ def get_default_config():
 
 
 def get_current_canvas():
-    """ Get the currently active canvas
-    
+    """Get the currently active canvas
+
     Returns None if there is no canvas available. A canvas is made
     active on initialization and before the draw event is emitted.
-    
+
     When a gloo object is created, it is associated with the currently
     active Canvas, or with the next Canvas to be created if there is
     no current Canvas. Use Canvas.set_current() to manually activate a
@@ -61,8 +61,7 @@ def get_current_canvas():
 
 
 def set_current_canvas(canvas):
-    """ Make a canvas active. Used primarily by the canvas itself.
-    """
+    """Make a canvas active. Used primarily by the canvas itself."""
     # Notify glir 
     canvas.context._do_CURRENT_command = True
     # Try to be quick
@@ -77,8 +76,7 @@ def set_current_canvas(canvas):
 
 
 def forget_canvas(canvas):
-    """ Forget about the given canvas. Used by the canvas when closed.
-    """
+    """Forget about the given canvas. Used by the canvas when closed."""
     cc = [c() for c in canvasses if c() is not None]
     while canvas in cc:
         cc.remove(canvas)
@@ -95,7 +93,7 @@ class GLContext(BaseGlooFunctions):
     shared : instance of GLContext | None
         The shared context.
     """
-    
+
     def __init__(self, config=None, shared=None):
         self._set_config(config)
         self._shared = shared if (shared is not None) else GLShared()
@@ -106,7 +104,7 @@ class GLContext(BaseGlooFunctions):
 
     def __repr__(self):
         return "<GLContext at 0x%x>" % id(self)
-    
+
     def _set_config(self, config):
         self._config = deepcopy(_default_dict)
         self._config.update(config or {})
@@ -116,9 +114,9 @@ class GLContext(BaseGlooFunctions):
                 raise KeyError('Key %r is not a valid GL config key.' % key)
             if not isinstance(val, type(_default_dict[key])):
                 raise TypeError('Context value of %r has invalid type.' % key)
-    
+
     def create_shared(self, name, ref):
-        """ For the app backends to create the GLShared object.
+        """For the app backends to create the GLShared object.
 
         Parameters
         ----------
@@ -130,35 +128,33 @@ class GLContext(BaseGlooFunctions):
         if self._shared is not None:
             raise RuntimeError('Can only set_shared once.')
         self._shared = GLShared(name, ref)
-    
+
     @property
     def config(self):
-        """ A dictionary describing the configuration of this GL context.
-        """
+        """A dictionary describing the configuration of this GL context."""
         return self._config
-    
+
     @property
     def glir(self):
-        """ The glir queue for the context. This queue is for objects
+        """The glir queue for the context. This queue is for objects
         that can be shared accross canvases (if they share a contex).
         """
         return self._glir
-    
+
     @property
     def shared(self):
-        """ Get the object that represents the namespace that can
+        """Get the object that represents the namespace that can
         potentially be shared between multiple contexts.
         """
         return self._shared
 
     @property
     def capabilities(self):
-        """ The OpenGL capabilities
-        """
+        """The OpenGL capabilities"""
         return deepcopy(self.shared.parser.capabilities)
 
     def flush_commands(self, event=None):
-        """ Flush
+        """Flush
 
         Parameters
         ----------
@@ -174,30 +170,30 @@ class GLContext(BaseGlooFunctions):
                 fbo = 0
             self.shared.parser.parse([('CURRENT', 0, fbo)])
         self.glir.flush(self.shared.parser)
-        
+
     def set_viewport(self, *args):
         BaseGlooFunctions.set_viewport(self, *args)
         self._last_viewport = args
-        
+
     def get_viewport(self):
         return self._last_viewport
 
 
 class GLShared(object):
-    """ Representation of a "namespace" that can be shared between
+    """Representation of a "namespace" that can be shared between
     different contexts. App backends can associate themselves with this
     object via add_ref().
-    
+
     This object can be used to establish whether two contexts/canvases
     share objects, and can be used as a placeholder to store shared
     information, such as glyph atlasses.
     """
-    
+
     # We keep a (weak) ref of each backend that gets associated with
     # this object. In theory, this means that multiple canvases can
     # be created and also deleted; as long as there is at least one
     # left, things should Just Work. 
-    
+
     def __init__(self):
         glir_file = config['glir_file']
 
@@ -208,22 +204,22 @@ class GLShared(object):
         self._parser = parser_cls()
         self._name = None
         self._refs = []
-    
+
     def __repr__(self):
         return "<GLShared of %s backend at 0x%x>" % (str(self.name), id(self))
-    
+
     @property
     def parser(self):
-        """The GLIR parser (shared between contexts) """
+        """The GLIR parser (shared between contexts)"""
         return self._parser
 
     @parser.setter
     def parser(self, parser):
         assert isinstance(parser, BaseGlirParser) or parser is None
         self._parser = parser
-    
+
     def add_ref(self, name, ref):
-        """ Add a reference for the backend object that gives access
+        """Add a reference for the backend object that gives access
         to the low level context. Used in vispy.app.canvas.backends.
         The given name must match with that of previously added
         references.
@@ -234,17 +230,17 @@ class GLShared(object):
             raise RuntimeError('Contexts can only share between backends of '
                                'the same type')
         self._refs.append(weakref.ref(ref))
-    
+
     @property
     def name(self):
-        """ The name of the canvas backend that this shared namespace is
+        """The name of the canvas backend that this shared namespace is
         associated with. Can be None.
         """
         return self._name
-    
+
     @property
     def ref(self):
-        """ A reference (stored internally via a weakref) to an object
+        """A reference (stored internally via a weakref) to an object
         that the backend system can use to obtain the low-level
         information of the "reference context". In Vispy this will
         typically be the CanvasBackend object.
@@ -260,18 +256,17 @@ class GLShared(object):
 
 
 class FakeCanvas(object):
-    """ Fake canvas to allow using gloo without vispy.app
-    
+    """Fake canvas to allow using gloo without vispy.app
+
     Instantiate this class to collect GLIR commands from gloo
     interactions. Call flush() in your draw event handler to execute
     the commands in the active contect.
     """
-    
+
     def __init__(self):
         self.context = GLContext()
         set_current_canvas(self)
-    
+
     def flush(self):
-        """ Flush commands. Call this after setting to context to current.
-        """
+        """Flush commands. Call this after setting to context to current."""
         self.context.flush_commands()
