@@ -2,6 +2,7 @@
 
 import json
 import tempfile
+from unittest import mock
 
 from vispy import config
 from vispy.app import Canvas
@@ -10,16 +11,11 @@ from vispy.testing import requires_application, requires_pyopengl, run_tests_if_
 
 import numpy as np
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
 
 def test_queue():
     q = glir.GlirQueue()
     parser = glir.GlirParser()
-    
+
     # Test adding commands and clear
     N = 5
     for i in range(N):
@@ -27,18 +23,18 @@ def test_queue():
     cmds = q.clear()
     for i in range(N):
         assert cmds[i] == ('FOO', 'BAR', i)
-    
+
     # Test filter 1
-    cmds1 = [('DATA', 1), ('SIZE', 1), ('FOO', 1), ('SIZE', 1), ('FOO', 1), 
+    cmds1 = [('DATA', 1), ('SIZE', 1), ('FOO', 1), ('SIZE', 1), ('FOO', 1),
              ('DATA', 1), ('DATA', 1)]
     cmds2 = [c[0] for c in q._shared._filter(cmds1, parser)]
     assert cmds2 == ['FOO', 'SIZE', 'FOO', 'DATA', 'DATA']
-    
+
     # Test filter 2
-    cmds1 = [('DATA', 1), ('SIZE', 1), ('FOO', 1), ('SIZE', 2), ('SIZE', 2), 
+    cmds1 = [('DATA', 1), ('SIZE', 1), ('FOO', 1), ('SIZE', 2), ('SIZE', 2),
              ('DATA', 2), ('SIZE', 1), ('FOO', 1), ('DATA', 1), ('DATA', 1)]
     cmds2 = q._shared._filter(cmds1, parser)
-    assert cmds2 == [('FOO', 1), ('SIZE', 2), ('DATA', 2), ('SIZE', 1), 
+    assert cmds2 == [('FOO', 1), ('SIZE', 2), ('DATA', 2), ('SIZE', 1),
                      ('FOO', 1), ('DATA', 1), ('DATA', 1)]
 
     # Define shader
@@ -50,7 +46,7 @@ def test_queue():
     assert 'highp' not in shader2
     assert 'mediump' not in shader2
     assert 'precision' not in shader2
-    
+
     # Convert for es2
     shader3 = glir.convert_shader('es2', shader2)
     # make sure precision float is still in the shader
@@ -72,8 +68,7 @@ def test_queue():
 
 @requires_application()
 def test_log_parser():
-    """Test GLIR log parsing
-    """
+    """Test GLIR log parsing"""
     glir_file = tempfile.TemporaryFile(mode='r+')
 
     config.update(glir_file=glir_file)
@@ -99,11 +94,14 @@ def test_log_parser():
     assert lines[i].startswith(expected[0])
     assert lines[i].endswith(expected[1])
     assert int(lines[i][len(expected[0]):-len(expected[1])]) is not None
-    i += 1
 
     # The 'CURRENT' command may have been called multiple times
-    while lines[i] == lines[i - 1]:
+    while lines[i].startswith('["CURRENT",'):
         i += 1
+        if lines[i] == json.dumps(['FUNC', 'colorMask', False, False, False, True]):
+            # Qt workaround, see #2040
+            i += 4
+
     assert lines[i] == json.dumps(['FUNC', 'clearColor', 1.0, 1.0, 1.0, 1.0])
     i += 1
     assert lines[i] == json.dumps(['FUNC', 'clear', 17664])
@@ -117,8 +115,7 @@ def test_log_parser():
 
 @requires_application()
 def test_capabilities():
-    """Test GLIR capability reporting
-    """
+    """Test GLIR capability reporting"""
     with Canvas() as c:
         capabilities = c.context.shared.parser.capabilities
         assert capabilities['max_texture_size'] is not None
