@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) Vispy Development Team. All Rights Reserved.
 # Distributed under the (new) BSD License. See LICENSE.txt for more info.
-
 # This module was taken from visvis
-"""
-This module produces functionality to read and write wavefront (.OBJ) files.
+"""This module produces functionality to read and write wavefront (.OBJ) files.
 
-http://en.wikipedia.org/wiki/Wavefront_.obj_file
+See `wikipedia <http://en.wikipedia.org/wiki/Wavefront_.obj_file>`_ for more details.
 
 The wavefront format is quite powerful and allows a wide variety of surfaces
 to be described.
@@ -20,9 +18,9 @@ The classes are written with compatibility of Python3 in mind.
 
 import numpy as np
 import time
+from gzip import GzipFile
 from os import path as op
 
-from ..ext.gzip_open import gzip_open
 from ..geometry import _calculate_normals
 from ..util import logger
 
@@ -53,21 +51,18 @@ class WavefrontReader(object):
 
     @classmethod
     def read(cls, fname):
-        """ read(fname, fmt)
-
-        This classmethod is the entry point for reading OBJ files.
+        """Entry point for reading OBJ files.
 
         Parameters
         ----------
         fname : str
             The name of the file to read.
-        fmt : str
-            Can be "obj" or "gz" to specify the file format.
+
         """
         # Open file
         fmt = op.splitext(fname)[1].lower()
         assert fmt in ('.obj', '.gz')
-        opener = open if fmt == '.obj' else gzip_open
+        opener = open if fmt == '.obj' else GzipFile
         with opener(fname, 'rb') as f:
             try:
                 reader = WavefrontReader(f)
@@ -85,9 +80,7 @@ class WavefrontReader(object):
         return mesh
 
     def readLine(self):
-        """ The method that reads a line and processes it.
-        """
-
+        """The method that reads a line and processes it."""
         # Read line
         line = self._f.readline().decode('ascii', 'ignore')
         if not line:
@@ -117,16 +110,14 @@ class WavefrontReader(object):
                            % line.strip())
 
     def readTuple(self, line, n=3):
-        """ Reads a tuple of numbers. e.g. vertices, normals or teture coords.
-        """
+        """Reads a tuple of numbers. e.g. vertices, normals or teture coords."""
         numbers = [num for num in line.split(' ') if num]
         return [float(num) for num in numbers[1:n + 1]]
 
     def readFace(self, line):
-        """ Each face consists of three or more sets of indices. Each set
+        """Each face consists of three or more sets of indices. Each set
         consists of 1, 2 or 3 indices to vertices/normals/texcords.
         """
-
         # Get parts (skip first)
         indexSets = [num for num in line.split(' ') if num][1:]
 
@@ -198,7 +189,7 @@ class WavefrontReader(object):
         return normals
 
     def finish(self):
-        """ Converts gathere lists to numpy arrays and creates
+        """Converts gathere lists to numpy arrays and creates
         BaseMesh instance.
         """
         self._vertices = np.array(self._vertices, 'float32')
@@ -228,7 +219,7 @@ class WavefrontWriter(object):
     @classmethod
     def write(cls, fname, vertices, faces, normals,
               texcoords, name='', reshape_faces=True):
-        """ This classmethod is the entry point for writing mesh data to OBJ.
+        """This classmethod is the entry point for writing mesh data to OBJ.
 
         Parameters
         ----------
@@ -251,7 +242,7 @@ class WavefrontWriter(object):
         if fmt not in ('.obj', '.gz'):
             raise ValueError('Filename must end with .obj or .gz, not "%s"'
                              % (fmt,))
-        opener = open if fmt == '.obj' else gzip_open
+        opener = open if fmt == '.obj' else GzipFile
         f = opener(fname, 'wb')
         try:
             writer = WavefrontWriter(f)
@@ -263,15 +254,14 @@ class WavefrontWriter(object):
             f.close()
 
     def writeLine(self, text):
-        """ Simple writeLine function to write a line of code to the file.
+        """Simple writeLine function to write a line of code to the file.
         The encoding is done here, and a newline character is added.
         """
         text += '\n'
         self._f.write(text.encode('ascii'))
 
     def writeTuple(self, val, what):
-        """ Writes a tuple of numbers (on one line).
-        """
+        """Writes a tuple of numbers (on one line)."""
         # Limit to three values. so RGBA data drops the alpha channel
         # Format can handle up to 3 texcords
         val = val[:3]
@@ -281,8 +271,7 @@ class WavefrontWriter(object):
         self.writeLine('%s %s' % (what, val))
 
     def writeFace(self, val, what='f'):
-        """ Write the face info to the net line.
-        """
+        """Write the face info to the net line."""
         # OBJ counts from 1
         val = [v + 1 for v in val]
         # Make string
@@ -299,9 +288,7 @@ class WavefrontWriter(object):
 
     def writeMesh(self, vertices, faces, normals, values,
                   name='', reshape_faces=True):
-        """ Write the given mesh instance.
-        """
-
+        """Write the given mesh instance."""
         # Store properties
         self._hasNormals = normals is not None
         self._hasValues = values is not None
