@@ -13,7 +13,7 @@ from ...app import Timer
 
 class MagnifyCamera(PanZoomCamera):
     """Camera implementing a MagnifyTransform combined with PanZoomCamera.
-    
+
     Parameters
     ----------
     size_factor : float
@@ -28,39 +28,39 @@ class MagnifyCamera(PanZoomCamera):
     This Camera uses the mouse cursor position to set the center position of
     the MagnifyTransform, and uses mouse wheel events to adjust the 
     magnification factor.
-    
+
     At high magnification, very small mouse movements can result in large
     changes, so we use a timer to animate transitions in the transform 
     properties.
-    
+
     The camera also adjusts the size of its "lens" area when the view is
     resized.
-
     """
+
     transform_class = MagnifyTransform
-    
+
     def __init__(self, size_factor=0.25, radius_ratio=0.9, **kwargs):
         # what fraction of the view width to use for radius
         self.size_factor = size_factor
-        
+
         # ratio of inner to outer lens radius
         self.radius_ratio = radius_ratio
-        
+
         # Extract kwargs for panzoom
         camkwargs = {}
         for key in ('parent', 'name', 'rect', 'aspect'):
             if key in kwargs:
                 camkwargs[key] = kwargs.pop(key)
-        
+
         # Create the mag transform - kwrds go here
         self.mag = self.transform_class(**kwargs)
-        
+
         # for handling smooth transitions
         self.mag_target = self.mag.mag
         self.mag._mag = self.mag_target
         self.mouse_pos = None
         self.timer = Timer(interval=0.016, connect=self.on_timer)
-        
+
         super(MagnifyCamera, self).__init__(**camkwargs)
 
         # This tells the camera to insert the magnification transform at the
@@ -72,16 +72,16 @@ class MagnifyCamera(PanZoomCamera):
         #    the scale factors implemented there should not change the shape
         #    of the lens.
         self.pre_transform = self.mag
-    
+
     def _viewbox_set(self, viewbox):
         PanZoomCamera._viewbox_set(self, viewbox)
-        
+
     def _viewbox_unset(self, viewbox):
         PanZoomCamera._viewbox_unset(self, viewbox)
         self.timer.stop()
-    
+
     def viewbox_mouse_event(self, event):
-        """ViewBox mouse event handler
+        """The ViewBox mouse event handler
 
         Parameters
         ----------
@@ -90,7 +90,7 @@ class MagnifyCamera(PanZoomCamera):
         """
         # When the attached ViewBox reseives a mouse event, it is sent to the
         # camera here.
-        
+
         self.mouse_pos = event.pos[:2]
         if event.type == 'mouse_wheel':
             # wheel rolled; adjust the magnification factor and hide the 
@@ -102,13 +102,13 @@ class MagnifyCamera(PanZoomCamera):
         else:
             # send everything _except_ wheel events to the superclass
             super(MagnifyCamera, self).viewbox_mouse_event(event)
-            
+
         # start the timer to smoothly modify the transform properties. 
         if not self.timer.running:
             self.timer.start()
-        
+
         self._update_transform()
-    
+
     def on_timer(self, event=None):
         """Timer event handler
 
@@ -120,24 +120,24 @@ class MagnifyCamera(PanZoomCamera):
         # Smoothly update center and magnification properties of the transform
         k = np.clip(100. / self.mag.mag, 10, 100)
         s = 10**(-k * event.dt)
-            
+
         c = np.array(self.mag.center)
         c1 = c * s + self.mouse_pos * (1-s)
-        
+
         m = self.mag.mag * s + self.mag_target * (1-s)
-        
+
         # If changes are very small, then it is safe to stop the timer.
         if (np.all(np.abs((c - c1) / c1) < 1e-5) and 
                 (np.abs(np.log(m / self.mag.mag)) < 1e-3)):
             self.timer.stop()
-            
+
         self.mag.center = c1
         self.mag.mag = m
-            
+
         self._update_transform()
 
     def viewbox_resize_event(self, event):
-        """ViewBox resize event handler
+        """The ViewBox resize event handler
 
         Parameters
         ----------
