@@ -11,18 +11,25 @@ from operator import mul
 
 
 def dtype_reduce(dtype, level=0, depth=0):
-    """
-    Try to reduce dtype up to a given level when it is possible
+    """Try to reduce dtype up to a given level when it is possible.
 
-    dtype =  [ ('vertex',  [('x', 'f4'), ('y', 'f4'), ('z', 'f4')]),
-               ('normal',  [('x', 'f4'), ('y', 'f4'), ('z', 'f4')]),
-               ('color',   [('r', 'f4'), ('g', 'f4'), ('b', 'f4'),
-                            ('a', 'f4')])]
+    Examples
+    --------
+    >>> dtype =  [ ('vertex',  [('x', 'f4'), ('y', 'f4'), ('z', 'f4')]),
+    ...            ('normal',  [('x', 'f4'), ('y', 'f4'), ('z', 'f4')]),
+    ...            ('color',   [('r', 'f4'), ('g', 'f4'), ('b', 'f4'),
+    ...                         ('a', 'f4')])]
+
+    level 0 result::
+
+        ['color,vertex,normal,', 10, 'float32']
+
+    level 1 result::
+
+        [['color', 4, 'float32']
+         ['normal', 3, 'float32']
+         ['vertex', 3, 'float32']]
 
-    level 0: ['color,vertex,normal,', 10, 'float32']
-    level 1: [['color', 4, 'float32']
-              ['normal', 3, 'float32']
-              ['vertex', 3, 'float32']]
     """
     dtype = np.dtype(dtype)
     fields = dtype.fields
@@ -45,7 +52,7 @@ def dtype_reduce(dtype, level=0, depth=0):
         # Get reduced fields
         for key, value in fields.items():
             dtype_list = dtype_reduce(value[0], level, depth + 1)
-            if type(dtype_list[0]) is str:
+            if isinstance(dtype_list[0], str):
                 items.append([key, dtype_list[1], dtype_list[2]])
             else:
                 items.append(dtype_list)
@@ -56,7 +63,7 @@ def dtype_reduce(dtype, level=0, depth=0):
         count = 0
         for i, item in enumerate(items):
             # One item is a list, we cannot reduce
-            if type(item[0]) is not str:
+            if not isinstance(item[0], str):
                 return items
             else:
                 if i == 0:
@@ -73,22 +80,20 @@ def dtype_reduce(dtype, level=0, depth=0):
 
 
 def fetchcode(utype, prefix=""):
-    """
-    Generate the GLSL code needed to retrieve fake uniform values from a
-    texture.
+    """Generate the GLSL code needed to retrieve fake uniform values from a texture.
 
+    Parameters
+    ----------
     uniforms : sampler2D
         Texture to fetch uniforms from
-
     uniforms_shape: vec3
         Size of texture (width,height,count) where count is the number of float
         to be fetched.
-
     collection_index: float
         Attribute giving the index of the uniforms to be fetched. This index
-       relates to the index in the uniform array from python side.
-    """
+        relates to the index in the uniform array from python side.
 
+    """
     utype = np.dtype(utype)
     _utype = dtype_reduce(utype, level=1)
 
